@@ -124,9 +124,6 @@ class NumerousBaseJob:
 
         t = states.get('t', t)
 
-        if t-t_end == 0:
-            self.subscribe = True
-
         if states:
             self.logger.debug('states loaded')
         return t, states
