@@ -294,7 +294,9 @@ class NumerousSystem:
 
         # Get values for helper variables
         item_class = simcomponent['item_class']
-        items = item_class.split(".")
+        items = []
+        if item_class:
+            items = item_class.split(".")
         component_name = simcomponent['name']
         component_id = simcomponent['uuid']
         container_id = simcomponent['containerID'] if 'containerID' in simcomponent else None
